function [xPos, sigDC, fDC] = sweeplp(optname, pos1, pos2, Nsweep)
% Sweep PRC macroscopicly in DRFPMI and generate plots.
% [xPos, sigDC, fDC] = sweeplp(optname, pos1, pos2, Nsweep)
% pos1 is a startine position of PRM, and pos2 is an ending position of
% PRM.
% 
% Example;
% sweeplp(optLCGT, 0, 20, 100);


  % Check number of input arguments
  if nargin < 4
    Nsweep = 100;
  elseif nargin > 4
    error('Too Many Arguments!')
  end
  
  % prepare some variables
  opt = optname;
  sweepset

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % PRC sweep
  len = getLinkNum(opt, 'PR', 'BS');
  posstart = [pos1 pos1];
  posend = [pos2 pos2];
  [xPos, sigDC, fDC] = sweepLink(opt, len, posstart, posend, Nsweep);
   
  %%% plot 
  fDCp = permute(fDC, [2, 3, 1]);

  subplot(2, 1, 1)
  n1 = getFieldAt(opt, nPR, 'fr');		% PR front input field
  semilogy(xPos(nPR, :), abs(fDCp(nSBa, :, n1)))
  title('l+ macroscopic sweep: RF component powers in the PRC')
  legend(num2str(vFrf(nSBa) / 1e6))
  grid on
  ylabel('Power[W]')

  subplot(2, 1, 2)
  n2 = getFieldAt(opt, nSR, 'fr');		% SR front input field
  semilogy(xPos(nPR, :), abs(fDCp(nSBa, :, n2)))
  title('l+ macroscopic sweep: RF component powers in the SRC')
  legend(num2str(vFrf(nSBa) / 1e6))
  grid on
  xlabel('PRM-BS distance[m]')
  ylabel('Power[W]')

  %%% maximum power and its position
  for rf = 1 : length(nSBa) 
    [a,b]=max(abs(fDCp(nSBa(rf), :, n1)));
    fprintf('Maximum peak in PRC: %gW for %gMHz at %8.8fm in the PRC.\n', a^2, vFrf(nSBa(rf))/1e6, xPos(nPR, b));
  end
  
  fprintf('\n');
  
  for rf = 1 : length(nSBa) 
    [a,b]=min(abs(fDCp(nSBa(rf), :, n1)));
    fprintf('Minimum peak in PRC: %gW for %gMHz at %8.8fm in the PRC.\n', a^2, vFrf(nSBa(rf))/1e6, xPos(nPR, b));
  end